@@ -34,7 +34,7 @@ use fields qw(
   _subs
 );
 
-our $VERSION = '1.303';
+our $VERSION = '1.310';
 
 use AnyEvent;
 use AnyEvent::Handle;
@@ -44,9 +44,27 @@ use Digest::SHA qw( sha1_hex );
 use Carp qw( confess );
 
 BEGIN {
-  our @EXPORT_OK = qw( E_CANT_CONN E_LOADING_DATASET E_IO
-      E_CONN_CLOSED_BY_REMOTE_HOST E_CONN_CLOSED_BY_CLIENT E_NO_CONN
-      E_OPRN_ERROR E_UNEXPECTED_DATA E_NO_SCRIPT E_READ_TIMEDOUT );
+  our @EXPORT_OK = qw(
+    E_CANT_CONN
+    E_LOADING_DATASET
+    E_IO
+    E_CONN_CLOSED_BY_REMOTE_HOST
+    E_CONN_CLOSED_BY_CLIENT
+    E_NO_CONN
+    E_OPRN_ERROR
+    E_UNEXPECTED_DATA
+    E_NO_SCRIPT
+    E_READ_TIMEDOUT
+    E_BUSY
+    E_MASTER_DOWN
+    E_MISCONF
+    E_READONLY
+    E_OOM
+    E_EXEC_ABORT
+    E_NO_AUTH
+    E_WRONG_TYPE
+    E_NO_REPLICAS
+  );
 
   our %EXPORT_TAGS = (
     err_codes => \@EXPORT_OK,
@@ -69,6 +87,15 @@ use constant {
   E_UNEXPECTED_DATA            => 10,
   E_NO_SCRIPT                  => 11,
   E_READ_TIMEDOUT              => 12,
+  E_BUSY                       => 13,
+  E_MASTER_DOWN                => 14,
+  E_MISCONF                    => 15,
+  E_READONLY                   => 16,
+  E_OOM                        => 17,
+  E_EXEC_ABORT                 => 18,
+  E_NO_AUTH                    => 19,
+  E_WRONG_TYPE                 => 20,
+  E_NO_REPLICAS                => 21,
 
   # Command status
   S_NEED_PERFORM => 1,
@@ -103,9 +130,18 @@ my %SPECIAL_CMDS = (
   multi => 1,
 );
 
-my %SPECIAL_ERR_PREFS = (
-  LOADING  => E_LOADING_DATASET,
-  NOSCRIPT => E_NO_SCRIPT,
+my %ERR_PREFIXES_MAP = (
+  LOADING    => E_LOADING_DATASET,
+  NOSCRIPT   => E_NO_SCRIPT,
+  BUSY       => E_BUSY,
+  MASTERDOWN => E_MASTER_DOWN,
+  MISCONF    => E_MISCONF,
+  READONLY   => E_READONLY,
+  OOM        => E_OOM,
+  EXECABORT  => E_EXEC_ABORT,
+  NOAUTH     => E_NO_AUTH,
+  WRONGTYPE  => E_WRONG_TYPE,
+  NOREPLICAS => E_NO_REPLICAS,
 );
 
 my %EVAL_CACHE;
@@ -457,9 +493,9 @@ sub _get_read_cb {
         }
         elsif ( $type eq '-' ) {
           my $err_code = E_OPRN_ERROR;
-          if ( $reply =~ m/^([A-Z]{3,})/ ) {
-            if ( exists( $SPECIAL_ERR_PREFS{ $1 } ) ) {
-              $err_code = $SPECIAL_ERR_PREFS{ $1 };
+          if ( $reply =~ m/^([A-Z]{3,}) / ) {
+            if ( exists( $ERR_PREFIXES_MAP{ $1 } ) ) {
+              $err_code = $ERR_PREFIXES_MAP{ $1 };
             }
           }
 
@@ -1385,10 +1421,9 @@ The C<on_error> callback is called, when some error occurred.
 Since version 1.300 of the client you can specify single, C<on_reply> callback,
 instead of two, C<on_done> and C<on_error> callbacks. The C<on_reply> callback
 is called in both cases: when operation was completed successfully and when some
-errors occurred. In first case to callback is passed only reply data. In second
-case to callback is passed three arguments: undef value, error mesage and error
-code. Also in second case first argument can contain reply data with error
-objects (see below).
+error occurred. In first case to callback is passed only reply data. In second
+case to callback is passed three arguments: C<undef> value or reply data with error
+objects (see below), error mesage and error code.
 
 =back
 
@@ -1888,24 +1923,11 @@ imported and used in expressions.
 
   use AnyEvent::Redis::RipeRedis qw( :err_codes );
 
-Error codes and constants corresponding to them:
-
-  1  - E_CANT_CONN
-  2  - E_LOADING_DATASET
-  3  - E_IO
-  4  - E_CONN_CLOSED_BY_REMOTE_HOST
-  5  - E_CONN_CLOSED_BY_CLIENT
-  6  - E_NO_CONN
-  9  - E_OPRN_ERROR
-  10 - E_UNEXPECTED_DATA
-  11 - E_NO_SCRIPT
-  12 - E_READ_TIMEDOUT
-
 =over
 
 =item E_CANT_CONN
 
-Can not connect to the server. All operations were aborted.
+Can't connect to the server. All operations were aborted.
 
 =item E_LOADING_DATASET
 
@@ -1939,10 +1961,6 @@ Operation error. For example, wrong number of arguments for a command.
 The client received unexpected data from the server. The connection to the Redis
 server was closed and all operations were aborted.
 
-=item E_NO_SCRIPT
-
-No matching script. Use the C<EVAL> command.
-
 =item E_READ_TIMEDOUT
 
 Read timed out. The connection to the Redis server was closed and all operations
@@ -1950,6 +1968,61 @@ were aborted.
 
 =back
 
+Error codes available since Redis 2.6.
+
+=over
+
+=item E_NO_SCRIPT
+
+No matching script. Use the C<EVAL> command.
+
+=item E_BUSY
+
+Redis is busy running a script. You can only call C<SCRIPT KILL>
+or C<SHUTDOWN NOSAVE>.
+
+=item E_MASTER_DOWN
+
+Link with MASTER is down and slave-serve-stale-data is set to 'no'.
+
+=item E_MISCONF
+
+Redis is configured to save RDB snapshots, but is currently not able to persist
+on disk. Commands that may modify the data set are disabled. Please check Redis
+logs for details about the error.
+
+=item E_READONLY
+
+You can't write against a read only slave.
+
+=item E_OOM
+
+Command not allowed when used memory > 'maxmemory'.
+
+=item E_EXEC_ABORT
+
+Transaction discarded because of previous errors.
+
+=back
+
+Error codes available since Redis 2.8.
+
+=over
+
+=item E_NO_AUTH
+
+Authentication required.
+
+=item E_WRONG_TYPE
+
+Operation against a key holding the wrong kind of value.
+
+=item E_NO_REPLICAS
+
+Not enough good slaves to write.
+
+=back
+
 =head1 DISCONNECTION
 
 When the connection to the server is no longer needed you can close it in three
@@ -1987,7 +2060,7 @@ method, will be completed correctly.
 
 =head2 connection_timeout( $seconds )
 
-Get or set the C<connection_timeout> of the client. Undef value resets the
+Get or set the C<connection_timeout> of the client. C<undef> value resets the
 C<connection_timeout> to default value.
 
 =head2 read_timeout( $seconds )
